==> pytool-3.1.0.tar.gz: pytool-3.1.0/setup.py <==
import multiprocessing, logging # Fix atexit bug
from setuptools import setup, find_packages


exec("c=__import__('compiler');a='__version__';l=[];g=lambda:[n.expr.value for"
        " n in l for o in n.nodes if o.name==a].pop();c.walk(c.parseFile('%s/_"
        "_init__.py'),type('v',(object,),{'visitAssign':lambda s,n:l.append(n)"
        "})());exec(a+'=g()');"%'pytool')


def readme():
    try:
        return open('README.rst').read()
    except:
        pass
    return ''

setup(
        name='pytool',
        version=__version__,
        author="Jacob Alheid",
        author_email="jake@about.me",
        description="A Collection of Python Tools",
        long_description=readme(),
        url='http://github.com/shakefu/pytool',
        packages=find_packages(exclude=['test']),
        # Remove this dependency_links after 3.2.0 makes it onto PyPI
        dependency_links=['http://github.com/shakefu/simplejson/tarball/master'
            '#egg=simplejson-3.2.0'],
        install_requires=['simplejson >= 3.2.0'],
        test_suite='nose.collector',
        tests_require=[
            'nose',
            'mock',
            ],
        classifiers=[
            'Development Status :: 5 - Production/Stable',
            'Intended Audience :: Developers',
            'License :: OSI Approved :: Apache Software License',
            'Operating System :: OS Independent',
            'Programming Language :: Python :: 2.7',
            'Topic :: Software Development :: Libraries',
            'Topic :: Utilities',
            ]
        )

==> pytool-3.10.1.tar.gz: pytool-3.10.1/setup.py <==
from setuptools import setup, find_packages


def readme():
    try:
        return open('README.rst').read()
    except:
        pass
    return ''


def version():
    try:
        import re
        return re.search("^__version__ = '(.*)'",
                open('pytool/__init__.py').read(), re.M).group(1)
    except:
        raise RuntimeError("Could not get version")


setup(
        name='pytool',
        version=version(),
        author="Jacob Alheid",
        author_email="jake@about.me",
        description="A Collection of Python Tools",
        long_description=readme(),
        url='http://github.com/shakefu/pytool',
        license='ALv2',
        packages=find_packages(exclude=['test']),
        install_requires=['simplejson >= 3.2.0', 'six'],
        test_suite='nose.collector',
        tests_require=[
            'nose',
            'mock',
            ],
        classifiers=[
            'Development Status :: 5 - Production/Stable',
            'Intended Audience :: Developers',
            'License :: OSI Approved :: Apache Software License',
            'Operating System :: OS Independent',
            'Programming Language :: Python :: 2.7',
            'Programming Language :: Python :: 3.3',
            'Programming Language :: Python :: 3.4',
            'Programming Language :: Python :: 3.5',
            'Programming Language :: Python :: 3.6',
            'Topic :: Software Development :: Libraries',
            'Topic :: Utilities',
            ]
        )
